@@ -244,7 +244,7 @@ impl Value {
                     value.encode_field(&value_desc, buf);
                 }
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
@@ -370,7 +370,7 @@ impl Value {
 
                 Ok(())
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
@@ -529,7 +529,7 @@ impl Value {
                     })
                     .sum::<usize>()
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
@@ -578,7 +578,7 @@ impl MapKey {
             (MapKey::String(value), Kind::String) => {
                 prost::encoding::string::encode(number, value, buf)
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
@@ -632,7 +632,7 @@ impl MapKey {
             (MapKey::String(value), Kind::String) => {
                 prost::encoding::string::merge(wire_type, value, buf, ctx)
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
@@ -676,7 +676,7 @@ impl MapKey {
             (MapKey::String(value), Kind::String) => {
                 prost::encoding::string::encoded_len(number, value)
             }
-            (value, ty) => unreachable!(
+            (value, ty) => panic!(
                 "mismatch between DynamicMessage value {:?} and type {:?}",
                 value, ty
             ),
